@@ -40,7 +40,7 @@ get_dataset <- function(set_name, api_key = NULL, show_progress = FALSE) {
        stop("Could not authenticate. Please check your API key!")
     } else if(status == 404) {
        stop(sprintf("The API responded with\n%s.\nAre you sure the requested set exists and is %s?",
-                    data$message,
+                    data$error,
                     ifelse(is.null(api_key), "public", "non-public")))
     } else {
       stop(sprintf("An error occurred when calling the api:\nStatus: %d\nContent:%s", response$status_code, content(response, as = "text")))
